Country class

Immutable country model.

Constructors

Country({required String name, required String isoCode, required String dialCode})
const

Properties

dialCode → String
final
flagEmoji → String
Emoji flag derived from ISO alpha-2 (lightweight, no assets).
no setter
hashCode → int
The hash code for this object.
no setterinherited
isoCode → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited