CountryPickerLocalizations class

Constructors

CountryPickerLocalizations(Locale locale)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
locale → Locale
final
noResults → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchHint → String
no setter
sheetTitle → String
no setter

Methods

countryName(String isoCode, String fallback) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → CountryPickerLocalizations

Constants

supportedLocales → const List<Locale>