CountryPickerStyle class

Customization options for the bottom sheet.

Constructors

CountryPickerStyle({String? sheetTitle, String? searchHintText, String? noResultsText, double cornerRadius = 20, EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 8), bool showSearch = true, Color? chipColor, Color? selectedTileColor, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? dialCodeTextStyle, TextStyle? searchTextStyle, InputBorder? searchBorder, double initialSheetSize = 0.85, double minSheetSize = 0.5, double maxSheetSize = 0.95})
const

Properties

chipColor → Color?
final
contentPadding → EdgeInsets
final
cornerRadius → double
final
dialCodeTextStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
initialSheetSize → double
final
maxSheetSize → double
final
minSheetSize → double
final
noResultsText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchBorder → InputBorder?
final
searchHintText → String?
final
searchTextStyle → TextStyle?
final
selectedTileColor → Color?
final
sheetTitle → String?
final
showSearch → bool
final
subtitleTextStyle → TextStyle?
final
titleTextStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveNoResults(BuildContext context) → String
resolveSearchHint(BuildContext context) → String
resolveSheetTitle(BuildContext context) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited